@@ -3,7 +3,7 @@
     Command line test
     ~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2019 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -200,8 +200,9 @@ def test_H_opt():
 def test_S_opt():
     o = check_success('-S', 'default', '-f', 'html', '-O', 'linenos=1')
     lines = o.splitlines()
-    for line in lines:
-        # every line is for a token class
+    for line in lines[5:]:
+        # every line is for a token class, except for the first 5 lines,
+        # which define styles for `pre` and line numbers
         parts = line.split()
         assert parts[0].startswith('.')
         assert parts[1] == '{'
