@@ -3,7 +3,7 @@
     Pygments HTML formatter tests
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2020 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -142,7 +142,7 @@ def test_valid_output():
 
 def test_get_style_defs_contains_pre_style():
     style_defs = HtmlFormatter().get_style_defs().splitlines()
-    assert style_defs[0] == 'pre { line-height: 125%; margin: 0; }'
+    assert style_defs[0] == 'pre { line-height: 125%; }'
 
 
 def test_get_style_defs_contains_default_line_numbers_styles():
