@@ -3,7 +3,7 @@
     Pygments IRC formatter tests
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2019 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -20,4 +20,4 @@ def test_correct_output():
     houtfile = StringIO()
     hfmt.format(tokensource, houtfile)
 
-    assert u'\x0302lambda\x03 x: \x0302123\x03\n' == houtfile.getvalue()
+    assert '\x0302lambda\x03 x: \x0302123\x03\n' == houtfile.getvalue()
