@@ -3,13 +3,15 @@
     Basic JavaLexer Test
     ~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2019 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+import time
+
 import pytest
 
-from pygments.token import Text, Name, Punctuation, Keyword, Number
+from pygments.token import Keyword, Name, Number, Punctuation, String, Text
 from pygments.lexers import JavaLexer
 
 
@@ -19,23 +21,23 @@ def lexer():
 
 
 def test_enhanced_for(lexer):
-    fragment = u'label:\nfor(String var2: var1) {}\n'
+    fragment = 'label:\nfor(String var2: var1) {}\n'
     tokens = [
-        (Name.Label, u'label:'),
-        (Text, u'\n'),
-        (Keyword, u'for'),
-        (Punctuation, u'('),
-        (Name, u'String'),
-        (Text, u' '),
-        (Name, u'var2'),
-        (Punctuation, u':'),
-        (Text, u' '),
-        (Name, u'var1'),
-        (Punctuation, u')'),
-        (Text, u' '),
-        (Punctuation, u'{'),
-        (Punctuation, u'}'),
-        (Text, u'\n'),
+        (Name.Label, 'label:'),
+        (Text, '\n'),
+        (Keyword, 'for'),
+        (Punctuation, '('),
+        (Name, 'String'),
+        (Text, ' '),
+        (Name, 'var2'),
+        (Punctuation, ':'),
+        (Text, ' '),
+        (Name, 'var1'),
+        (Punctuation, ')'),
+        (Text, ' '),
+        (Punctuation, '{'),
+        (Punctuation, '}'),
+        (Text, '\n'),
     ]
     assert list(lexer.get_tokens(fragment)) == tokens
 
@@ -76,3 +78,24 @@ def test_numeric_literals(lexer):
         (Text, '\n')
     ]
     assert list(lexer.get_tokens(fragment)) == tokens
+
+
+@pytest.mark.parametrize(
+    'text',
+    (
+        '""', '"abc"', '"ひらがな"', '"123"',
+        '"\\\\"', '"\\t"' '"\\""',
+    ),
+)
+def test_string_literals_positive_match(lexer, text):
+    """Test positive matches for string literals."""
+    tokens = list(lexer.get_tokens_unprocessed(text))
+    assert all([token is String for _, token, _ in tokens])
+    assert ''.join([value for _, _, value in tokens]) == text
+
+
+def test_string_literals_backtracking(lexer):
+    """Test catastrophic backtracking for string literals."""
+    start_time = time.time()
+    list(lexer.get_tokens_unprocessed('"' + '\\' * 100))
+    assert time.time() - start_time < 1, 'possible backtracking bug'
