@@ -3,16 +3,17 @@
     Pygments tests for using()
     ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2019 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-import unittest
+from pytest import raises
 
 from pygments.lexer import using, bygroups, this, RegexLexer
 from pygments.token import String, Text, Keyword
 
-class TestLexer(RegexLexer):
+
+class MyLexer(RegexLexer):
     tokens = {
         'root': [
             (r'#.*',
@@ -27,14 +28,13 @@ class TestLexer(RegexLexer):
     }
 
 
-class UsingStateTest(unittest.TestCase):
-    def test_basic(self):
-        expected = [(Text, 'a'), (String, '"'), (Keyword, 'bcd'),
-                    (String, '"'), (Text, 'e\n')]
-        t = list(TestLexer().get_tokens('a"bcd"e'))
-        self.assertEqual(t, expected)
+def test_basic():
+    expected = [(Text, 'a'), (String, '"'), (Keyword, 'bcd'),
+                (String, '"'), (Text, 'e\n')]
+    assert list(MyLexer().get_tokens('a"bcd"e')) == expected
 
-    def test_error(self):
-        def gen():
-            return list(TestLexer().get_tokens('#a'))
-        self.assertRaises(KeyError, gen)
+
+def test_error():
+    def gen():
+        return list(MyLexer().get_tokens('#a'))
+    assert raises(KeyError, gen)
